@@ -53,6 +53,25 @@ class JiraAgileToolBox(object):
         return sum_of_story_points_per_state
 
     def get_custom_field_from_name(self, name):
+        """
+        helper method to find custom fields
+
+        :param name: name of the field you want the "customxxxxx" value from
+        :return:
+        """
         for field in self._jira_client.fields():
             if field["name"] == name:
                 return field["id"]
+
+    def rank_issues_by_list(self, ranked_list, on_top_of_issue):
+        """
+        sorts the provided list by rank on top of the latter issue
+
+        :param ranked_list: list of issues to be sorted by rank index 0 has highest rank
+        :param on_top_of_issue: issue on top of which these issues need to land
+        """
+        reversed_list = ranked_list[::-1]
+        reversed_list.insert(0, on_top_of_issue)
+        for i, value in enumerate(reversed_list):
+            if i < len(reversed_list) - 1:
+                self._jira_client.rank(reversed_list[i + 1].key, value.key)
